========
Contents
========

.. toctree::
   :maxdepth: 2

   readme
   contributing
   authors
   changelog
   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
